# luketils

![Downloads](https://img.shields.io/pypi/dm/luketils.svg)
![Python](https://img.shields.io/badge/python-v3.7.0+-success.svg)
[![Contributions Welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/lukewood/luketils/issues)

`luketils` is a Python utility package aimed at machine learning practitioners.
The goal of the package is to provide useful utilities in a coherently designed and
powerful API.

_Call for Contributions:_ *luketils is actively seeking contributions!  Please see the [Call for Contributions](#call_for_contributions) section below!*

## Quick Links

- [API Docs](https://luketils.com)
- [GitHub Repo](https://github.com/lukewood/luketils)
- Examples and guides coming soon...

## Call for Contributions

I'm hoping to crowdsource `luketils` and gather as many
useful machine learning oriented Python utilities as possible.  Have something useful?
Open a PR!  I'll give it a review!  

Don't have an idea?  Check out the [issues list](https://github.com/lukewood/luketils)!  Any PR addressing an issue is welcome.

## Thanks

Thank you to all of our wonderful contributors!
